@@ -1,15 +1,11 @@
-"""Custom exceptions for the html-to-markdown library."""
-
 from __future__ import annotations
 
 
 class HtmlToMarkdownError(Exception):
-    """Base exception for all html-to-markdown errors."""
+    pass
 
 
 class MissingDependencyError(HtmlToMarkdownError):
-    """Raised when an optional dependency is required but not installed."""
-
     def __init__(self, dependency: str, install_command: str | None = None) -> None:
         self.dependency = dependency
         self.install_command = install_command
@@ -22,8 +18,6 @@ class MissingDependencyError(HtmlToMarkdownError):
 
 
 class InvalidParserError(HtmlToMarkdownError):
-    """Raised when an invalid parser is specified."""
-
     def __init__(self, parser: str, available_parsers: list[str]) -> None:
         self.parser = parser
         self.available_parsers = available_parsers
@@ -33,17 +27,18 @@ class InvalidParserError(HtmlToMarkdownError):
 
 
 class EmptyHtmlError(HtmlToMarkdownError):
-    """Raised when the input HTML is empty."""
-
     def __init__(self) -> None:
         super().__init__("The input HTML is empty.")
 
 
 class ConflictingOptionsError(HtmlToMarkdownError):
-    """Raised when conflicting options are specified."""
-
     def __init__(self, option1: str, option2: str) -> None:
         self.option1 = option1
         self.option2 = option2
 
         super().__init__(f"Only one of '{option1}' and '{option2}' can be specified.")
+
+
+class InvalidEncodingError(HtmlToMarkdownError):
+    def __init__(self, encoding: str) -> None:
+        super().__init__(f"The specified encoding ({encoding}) is not valid.")
